/********************************************************************************
** Form generated from reading UI file 'defaultappspage.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DEFAULTAPPSPAGE_H
#define UI_DEFAULTAPPSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_DefaultAppsPage
{
public:
    QGridLayout *gridLayout_8;
    QLabel *label_1;
    QGridLayout *gridLayout;
    QLabel *label_2;
    QComboBox *terminalComboBox;
    QPushButton *terminalButton;
    QLabel *label_3;
    QComboBox *browserComboBox;
    QPushButton *browserButton;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *DefaultAppsPage)
    {
        if (DefaultAppsPage->objectName().isEmpty())
            DefaultAppsPage->setObjectName(QStringLiteral("DefaultAppsPage"));
        DefaultAppsPage->resize(340, 135);
        gridLayout_8 = new QGridLayout(DefaultAppsPage);
        gridLayout_8->setObjectName(QStringLiteral("gridLayout_8"));
        label_1 = new QLabel(DefaultAppsPage);
        label_1->setObjectName(QStringLiteral("label_1"));
        QFont font;
        font.setBold(true);
        font.setWeight(75);
        label_1->setFont(font);

        gridLayout_8->addWidget(label_1, 0, 0, 1, 1);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        label_2 = new QLabel(DefaultAppsPage);
        label_2->setObjectName(QStringLiteral("label_2"));

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        terminalComboBox = new QComboBox(DefaultAppsPage);
        terminalComboBox->setObjectName(QStringLiteral("terminalComboBox"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(terminalComboBox->sizePolicy().hasHeightForWidth());
        terminalComboBox->setSizePolicy(sizePolicy);
        terminalComboBox->setEditable(true);

        gridLayout->addWidget(terminalComboBox, 0, 1, 1, 1);

        terminalButton = new QPushButton(DefaultAppsPage);
        terminalButton->setObjectName(QStringLiteral("terminalButton"));

        gridLayout->addWidget(terminalButton, 0, 2, 1, 1);

        label_3 = new QLabel(DefaultAppsPage);
        label_3->setObjectName(QStringLiteral("label_3"));

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        browserComboBox = new QComboBox(DefaultAppsPage);
        browserComboBox->setObjectName(QStringLiteral("browserComboBox"));
        sizePolicy.setHeightForWidth(browserComboBox->sizePolicy().hasHeightForWidth());
        browserComboBox->setSizePolicy(sizePolicy);
        browserComboBox->setEditable(true);

        gridLayout->addWidget(browserComboBox, 1, 1, 1, 1);

        browserButton = new QPushButton(DefaultAppsPage);
        browserButton->setObjectName(QStringLiteral("browserButton"));

        gridLayout->addWidget(browserButton, 1, 2, 1, 1);

        verticalSpacer = new QSpacerItem(118, 186, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(verticalSpacer, 2, 1, 1, 1);


        gridLayout_8->addLayout(gridLayout, 1, 0, 1, 1);


        retranslateUi(DefaultAppsPage);

        QMetaObject::connectSlotsByName(DefaultAppsPage);
    } // setupUi

    void retranslateUi(QWidget *DefaultAppsPage)
    {
        label_1->setText(QApplication::translate("DefaultAppsPage", "Default Applications", Q_NULLPTR));
        label_2->setText(QApplication::translate("DefaultAppsPage", "Terminal Emulation:", Q_NULLPTR));
        terminalButton->setText(QApplication::translate("DefaultAppsPage", "Search...", Q_NULLPTR));
        label_3->setText(QApplication::translate("DefaultAppsPage", "Web Browser:", Q_NULLPTR));
        browserButton->setText(QApplication::translate("DefaultAppsPage", "Search...", Q_NULLPTR));
        Q_UNUSED(DefaultAppsPage);
    } // retranslateUi

};

namespace Ui {
    class DefaultAppsPage: public Ui_DefaultAppsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DEFAULTAPPSPAGE_H
