/********************************************************************************
** Form generated from reading UI file 'basicsettings.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BASICSETTINGS_H
#define UI_BASICSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_BasicSettings
{
public:
    QGridLayout *gridLayout_3;
    QLabel *label;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QComboBox *wmComboBox;
    QPushButton *findWmButton;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout;
    QPushButton *startButton;
    QPushButton *stopButton;
    QSpacerItem *horizontalSpacer;
    QTreeView *moduleView;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout;
    QCheckBox *leaveConfirmationCheckBox;
    QCheckBox *lockBeforePowerActionsCheckBox;

    void setupUi(QWidget *BasicSettings)
    {
        if (BasicSettings->objectName().isEmpty())
            BasicSettings->setObjectName(QStringLiteral("BasicSettings"));
        BasicSettings->resize(322, 380);
        gridLayout_3 = new QGridLayout(BasicSettings);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        label = new QLabel(BasicSettings);
        label->setObjectName(QStringLiteral("label"));
        QFont font;
        font.setBold(true);
        font.setWeight(75);
        label->setFont(font);

        gridLayout_3->addWidget(label, 0, 0, 1, 1);

        groupBox = new QGroupBox(BasicSettings);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        wmComboBox = new QComboBox(groupBox);
        wmComboBox->setObjectName(QStringLiteral("wmComboBox"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(wmComboBox->sizePolicy().hasHeightForWidth());
        wmComboBox->setSizePolicy(sizePolicy);
        wmComboBox->setEditable(true);

        gridLayout_2->addWidget(wmComboBox, 0, 0, 1, 1);

        findWmButton = new QPushButton(groupBox);
        findWmButton->setObjectName(QStringLiteral("findWmButton"));

        gridLayout_2->addWidget(findWmButton, 0, 1, 1, 1);


        gridLayout_3->addWidget(groupBox, 1, 0, 1, 1);

        groupBox_2 = new QGroupBox(BasicSettings);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        gridLayout = new QGridLayout(groupBox_2);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        startButton = new QPushButton(groupBox_2);
        startButton->setObjectName(QStringLiteral("startButton"));

        gridLayout->addWidget(startButton, 7, 1, 1, 1);

        stopButton = new QPushButton(groupBox_2);
        stopButton->setObjectName(QStringLiteral("stopButton"));

        gridLayout->addWidget(stopButton, 7, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 7, 0, 1, 1);

        moduleView = new QTreeView(groupBox_2);
        moduleView->setObjectName(QStringLiteral("moduleView"));
        moduleView->setAlternatingRowColors(true);
        moduleView->setRootIsDecorated(false);
        moduleView->setHeaderHidden(true);
        moduleView->header()->setStretchLastSection(false);

        gridLayout->addWidget(moduleView, 0, 0, 1, 3);


        gridLayout_3->addWidget(groupBox_2, 2, 0, 1, 1);

        groupBox_3 = new QGroupBox(BasicSettings);
        groupBox_3->setObjectName(QStringLiteral("groupBox_3"));
        verticalLayout = new QVBoxLayout(groupBox_3);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        leaveConfirmationCheckBox = new QCheckBox(groupBox_3);
        leaveConfirmationCheckBox->setObjectName(QStringLiteral("leaveConfirmationCheckBox"));

        verticalLayout->addWidget(leaveConfirmationCheckBox);

        lockBeforePowerActionsCheckBox = new QCheckBox(groupBox_3);
        lockBeforePowerActionsCheckBox->setObjectName(QStringLiteral("lockBeforePowerActionsCheckBox"));

        verticalLayout->addWidget(lockBeforePowerActionsCheckBox);


        gridLayout_3->addWidget(groupBox_3, 3, 0, 1, 1);


        retranslateUi(BasicSettings);

        QMetaObject::connectSlotsByName(BasicSettings);
    } // setupUi

    void retranslateUi(QWidget *BasicSettings)
    {
        label->setText(QApplication::translate("BasicSettings", "Basic Settings", Q_NULLPTR));
        groupBox->setTitle(QApplication::translate("BasicSettings", "Window Manager", Q_NULLPTR));
        findWmButton->setText(QApplication::translate("BasicSettings", "Search...", Q_NULLPTR));
        groupBox_2->setTitle(QApplication::translate("BasicSettings", "LXQt Modules", Q_NULLPTR));
        startButton->setText(QApplication::translate("BasicSettings", "Start", Q_NULLPTR));
        stopButton->setText(QApplication::translate("BasicSettings", "Stop", Q_NULLPTR));
        groupBox_3->setTitle(QApplication::translate("BasicSettings", "Leave Session", Q_NULLPTR));
        leaveConfirmationCheckBox->setText(QApplication::translate("BasicSettings", "Ask for confirmation to leave session", Q_NULLPTR));
        lockBeforePowerActionsCheckBox->setText(QApplication::translate("BasicSettings", "Lock screen before suspending/hibernating", Q_NULLPTR));
        Q_UNUSED(BasicSettings);
    } // retranslateUi

};

namespace Ui {
    class BasicSettings: public Ui_BasicSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BASICSETTINGS_H
